! $Id: parameters_SM_ac.f90,v 1.6 2001/04/11 08:44:34 kilian Exp $
!
! Copyright (C) 2000 by Thorsten Ohl <ohl@hep.tu-darmstadt.de>
! and others
!
! O'Mega is free software; you can redistribute it and/or modify it
! under the terms of the GNU General Public License as published by 
! the Free Software Foundation; either version 2, or (at your option)
! any later version.
!
! O'Mega is distributed in the hope that it will be useful, but
! WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
! GNU General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this program; if not, write to the Free Software
! Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
module omega_parameters_whizard
  use omega_kinds !NODEP!
  use omega_parameters !NODEP!
  use parameters
  implicit none
  private
  public :: import_from_whizard
contains
  subroutine import_from_whizard (par)
    type(parameter_set), intent(in) :: par
    real(kind=omega_prec) :: e, g, sinthw, costhw, qelep, qeup, qedwn, v
    mass(1:27) = 0
    width(1:27) = 0
    mass(3) = par%Ms
    mass(4) = par%Mc
    mass(5) = par%Mb
    mass(6) = par%Mtop
    width(6) = par%wtop
    mass(11) = par%Me
    mass(13) = par%Mm
    mass(15) = par%Mt
    mass(23) = par%mZ
    width(23) = par%wZ
    mass(24) = par%mW
    width(24) = par%wW
    mass(25) = par%mH
    width(25) = par%wH
    mass(26) =  xi0 * mass(23)
    width(26) =  0
    mass(27) =  xipm * mass(24)
    width(27) =  0
    v = 2 * par%MW * par%SW / par%EE 
    e = par%EE
    sinthw = par%SW
    sin2thw = sinthw**2
    costhw = par%CW
    qelep = - 1
    qeup = 2.0_omega_prec / 3.0_omega_prec
    qedwn = - 1.0_omega_prec / 3.0_omega_prec
    g = e / sinthw
    gcc = - g / 2 / sqrt (2.0_double)
    gncneu(1) = - g / 2 / costhw * ( + 0.5_double)
    gnclep(1) = - g / 2 / costhw * ( - 0.5_double - 2 * qelep * sin2thw)
    gncup(1)  = - g / 2 / costhw * ( + 0.5_double - 2 * qeup  * sin2thw)
    gncdwn(1) = - g / 2 / costhw * ( - 0.5_double - 2 * qedwn * sin2thw)
    gncneu(2) = - g / 2 / costhw * ( + 0.5_double)
    gnclep(2) = - g / 2 / costhw * ( - 0.5_double)
    gncup(2)  = - g / 2 / costhw * ( + 0.5_double)
    gncdwn(2) = - g / 2 / costhw * ( - 0.5_double)
    qlep = - e * qelep
    qup = - e * qeup
    qdwn = - e * qedwn
    qw = e
    iqw = (0,1)*qw
    gzww = g * costhw
    igzww = (0,1)*gzww
    gwww = g
    igwww = (0,1)*gwww
    ghww = mass(24) * g * par%fhvv
    ghhww = (0,1) * g / Sqrt(2._omega_prec) * Sqrt(par%fhhvv)
    ghzz = mass(23) * g / costhw * par%fhvv
    ghhzz = (0,1) * g / costhw / Sqrt(2._omega_prec) * Sqrt(par%fhhvv)
!     ghww = mass(24) * g
!     ghhww = (0,1) * g / Sqrt(2._omega_prec)
!     ghzz = mass(23) * g / costhw
!     ghhzz = (0,1) * g / costhw / Sqrt(2._omega_prec)
    ghtt = - mass(6) / v
    ghbb = - mass(5) / v
    ghcc = - mass(4) / v
    ghtautau = - mass(15) / v
    gh3 = - 3 * par%MH**2 / v * par%fhhh
    gh4 = par%MH / v * Sqrt(par%fhhhh)
!     gh3 = - 3 * par%MH**2 / v
!     gh4 = par%MH / v
    ig1a = iqw * g1a
    ig1z = igzww * g1z
    ig1pka = iqw * (g1a + kappaa) / 2
    ig1pkz = igzww * (g1z + kappaz) / 2
    ig1mka = iqw * (g1a - kappaa) / 2
    ig1mkz = igzww * (g1z - kappaz) / 2
    ikmg1a = ig1mka
    ikmg1z = ig1mkz
    ila = iqw * lambdaa / (mass(24)*mass(24))
    ilz = igzww * lambdaz / (mass(24)*mass(24))
!     ialww0 = 0
!     ialww2 = 0
!     ialzw1 = 0
!     ialzw0 = 0
!     ialzz  = 0
    ialww0 = g**2 * sqrt (-cmplx(par%a4 + 2 * par%a5, kind=omega_prec))
    ialww2 = g**2 * sqrt (-cmplx(2 * par%a4, kind=omega_prec))
    ialzw1 = g**2 / costhw * sqrt (-cmplx(par%a4 + par%a6, kind=omega_prec))
    ialzw0 = g**2 / costhw &
         & * sqrt (-cmplx(2 * (par%a5 + par%a7), kind=omega_prec))
    ialzz  = g**2 / (costhw*costhw) &
         & * sqrt (-cmplx(2 * (par%a4 + par%a5 + (par%a6+par%a7+par%a10)*2), &
         &                kind=omega_prec))
  end subroutine import_from_whizard
end module omega_parameters_whizard
